@@ -70,8 +70,10 @@ class sentence_tranformer():
             print('initializing the model...')
             if lang.lower() == 'en':
                 self.model = SentenceTransformer('all-MiniLM-L6-v2')
+                print('done...')
             else:
-                self.model = SentenceTransformer('paraphrase-multilingual-mpnet-base-v2')
+                self.model = SentenceTransformer('distiluse-base-multilingual-cased-v1')
+                print('done...')
             # else:
             #     raise Exception('unknown language entered')
 
